@@ -1,18 +1,20 @@
-skip_if_no_redis <- function() {
-  testthat::skip_if_not_installed("redux")
-  if (redux::redis_available()) {
-    return()
-  }
-  skip("redis is not available")
-}
+## helper for tests --------------------------------------
+
+createKey <- function() paste0(
+  "test_nodbi_",
+  format(Sys.time(),
+         "%Y-%m-%d_%H-%M-%S",
+         tz = "UTC"), "_",
+  paste0(sample(letters, 4), collapse = "")
+)
 
 skip_if_no_couchdb <- function() {
+  testthat::skip_if_not_installed("sofa")
   COUCHDB_TEST_USER <- Sys.getenv("COUCHDB_TEST_USER")
   COUCHDB_TEST_PWD <- Sys.getenv("COUCHDB_TEST_PWD")
-  testthat::skip_if_not_installed("sofa")
   if (inherits(try(
     src_couchdb(user = COUCHDB_TEST_USER, pwd = COUCHDB_TEST_PWD),
-      silent = TRUE), "try-error")) {
+    silent = TRUE), "try-error")) {
     skip("couchdb is not available")
   }
 }
@@ -26,7 +28,15 @@ skip_if_no_mongo <- function() {
 
 skip_if_no_sqlite <- function() {
   testthat::skip_if_not_installed("RSQLite")
-  if (inherits(try(src_sqlite(), silent = TRUE), "try-error")) {
+  if (inherits(try(tmp <- src_sqlite(), silent = TRUE), "try-error")) {
     skip("sqlite is not available")
   }
+  RSQLite::dbDisconnect(tmp$con)
+}
+
+skip_if_no_elastic <- function() {
+  testthat::skip_if_not_installed("elastic")
+  if (inherits(try(src_elastic(), silent = TRUE), "try-error")) {
+    skip("elasticsearch is not available")
+  }
 }
